-- Servo driver for a skid steering vehicle with an active castor/tailwheel/rudder
-- For a rover the castor must be controlable from -90 to 90 degrees to make pivot turning possible
--
-- The following parameters should be set:
--     
--     SERVO5_FUNCTION = 98 (Script 5)
-- 
-- The castor servo/actuator should be connected to the autopilot's output5
--
-- CAUTION: This script only works for Rover/Boat


local K_SCRIPTING5 = 98 -- TailWheel

local CONTROL_OUTPUT_THROTTLE = 3
local CONTROL_OUTPUT_YAW = 4
local TWSteering = 0
local deadzone = 0.01
function update()
  if not arming:is_armed() then
    -- if not armed move steering and throttle to mid
    SRV_Channels:set_output_norm(K_SCRIPTING5, 0)
   
  else
    -- retrieve high level steering and throttle control outputs from vehicle in -1 to +1 range
    local steering = vehicle:get_control_output(CONTROL_OUTPUT_YAW)
    local throttle = vehicle:get_control_output(CONTROL_OUTPUT_THROTTLE)
    if (steering and throttle) then
		TWSteering = (math.atan(steering/throttle) * (180 / math.pi))/90
		if steering == 0 and throttle == 0 then
			TWSteering = 0
		end
		if steering > -deadzone and steering < deadzone then
			TWSteering = 0
		end
		
      
      SRV_Channels:set_output_norm(K_SCRIPTING5, TWSteering)
      
    end
  end
  return update, 10 -- run at 100hz
end

gcs:send_text(6, "tailwheel.lua is running")
return update()